@@ -900,15 +900,14 @@ class Grid:
         """
 
         # Detect if shifting the node would make it leave image boundary
-        if not allow_shifting_node_outside_boundary:
-            new_coord_within_boundary = (
-                self.__nodes['pixel_x_axis'][node] +
-                delta_x <= self.get_image().shape[0]
-                and self.__nodes['pixel_x_axis'][node] + delta_x >= 0
-                and self.__nodes[
-                    'pixel_y_axis'][node] + delta_y <= self.get_image().shape[1]
-                and self.__nodes[
-                    'pixel_y_axis'][node] + delta_y >= 0)
+        new_coord_within_boundary = (
+            self.get_nodes['pixel_x_axis'][node] +
+            delta_x <= self.get_image().shape[0]
+            and self.get_nodes['pixel_x_axis'][node] + delta_x >= 0
+            and self.get_nodes[
+                'pixel_y_axis'][node] + delta_y <= self.get_image().shape[1]
+            and self.get_nodes[
+                'pixel_y_axis'][node] + delta_y >= 0)
 
         if new_coord_within_boundary or allow_shifting_node_outside_boundary:
             # shift node
